#
# spec file for package php7-phalcon
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name           phalcon
%define _cname          cphalcon
%define _php            php7
%define _architecture   %([[ %{_arch} == "i586" ]] && echo "32bits" || echo "64bits")

Name:           %{_php}-phalcon
Version:        3.3.2
Release:        lp150.1.1
Summary:        PHP7 Extension Module
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Servers
Url:            http://phalconphp.com/
Source0:        https://github.com/%{_name}/%{_cname}/archive/v%{version}.tar.gz#/%{_cname}-%{version}.tar.gz
BuildRequires:  %{_php}-ctype
BuildRequires:  %{_php}-devel
BuildRequires:  %{_php}-json
BuildRequires:  %{_php}-pdo
BuildRequires:  gcc
Requires:       %{_php}-mysql

%description
Phalcon is an open source, full stack framework for PHP 5
written as a C-extension, optimized for high performance.
You don't need learn or use the C language, since the functionality
is exposed as PHP classes ready for you to use. Zephir is a high level
language, something between C and PHP. It’s both dynamic and static
typed and it supports just the features we need to create and maintain
a project like Phalcon.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n %{_cname}-%{version}

%build
cd build/%{_php}/%{_architecture}
phpize
%configure --enable-%{_name}
make VERBOSE=1 %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_libdir}/%{_php}/extensions
mkdir -p %{buildroot}%{_sysconfdir}/%{_php}/conf.d
cd build/%{_php}/%{_architecture}
make INSTALL_ROOT=%{buildroot} install-modules

echo "; comment out next line to disable %{_name} extension in php" > %{buildroot}/%{_sysconfdir}/%{_php}/conf.d/%{_name}.ini
echo "extension=%{_name}.so" >> %{buildroot}/%{_sysconfdir}/%{_php}/conf.d/%{_name}.ini

%files
%defattr(644,root,root,755)
%doc CHANGELOG.md CONTRIBUTING.md README.md
%{_libdir}/%{_php}/extensions/%{_name}.so
%config(noreplace) %{_sysconfdir}/%{_php}/conf.d/%{_name}.ini

%changelog
* Fri Mar 30 2018 fisiu@opensuse.org
- Update to 3.3.2:
  * Fixed Phalcon\Db\Dialect\Mysql::modifyColumn to produce valid SQL for
    renaming the column
  * Fixed Phalcon\Forms\Form::getMessages to return back previous behaviour
  * Fixed Phalcon\Mvc\Model\Behavior\SoftDelete::notify to solve
    the exception that soft deletion renamed model
  * Fixed E_DEPRECATED error for each() in Phalcon\Debug\Dump
* Tue Jan 16 2018 fisiu@opensuse.org
- Update to 3.3.1:
  * Added support of PHP 7.2 and initial support of PHP 7.3
  * Added support for switch/case syntax to the Volt Engine
  * Added Phalcon\Logger\Adapter\Blackhole
  * Added Phalcon\Http\Request::hasHeader to check if certain header exists
  * Added support of 103 (Early Hint) HTTP status code
  * Added router:beforeMount event to Router::mount
  * Added ability to use PDO option aliases on database connect
  * Added Phalcon\Mvc\Model\MetaData\Apcu
  * Added ability to use string(file path) as a argument in Phalcon\Config\Factory::load()
  * Changed Phalcon\Mvc\Model to allow to pass a transaction within the query context
  * Many other fixes and improvements.
* Mon Oct 23 2017 fisiu@opensuse.org
- Update to 3.2.4:
  * Fix regression by removing injection of dispatcher's parameters.
* Fri Oct 20 2017 fisiu@opensuse.org
- Update to 3.2.3:
  * Minor fixes arround Mvc\Model, View and Query.
* Wed Oct 11 2017 fisiu@opensuse.org
- Don't generate c from zephir. Use c code provided by upstream.
- Drop zephir-0.9.11.tar.gz.
* Fri Aug 18 2017 fisiu@opensuse.org
- Update Phalcon to 3.2.2 and use zephir 0.9.11:
  * Bug fix release.
* Wed Aug  2 2017 tchvatal@suse.com
- Drop the php5 part to keep only php7 due to the php5 removal
* Wed Jul 12 2017 fisiu@opensuse.org
- Update version to 3.2.1:
  * Added Phalcon\Db\Dialect\Mysql::getForeignKeyChecks to generate a SQL to
    check the foreign key settings
  * Many bugfixes.
* Fri Jun 23 2017 fisiu@opensuse.org
- Update version to 3.2.0 and build with zephir 0.9.9.
* Mon Apr 10 2017 fisiu@opensuse.org
- Update Phalcon to 3.1.2 and use zephir 0.9.7.
* Tue Dec 20 2016 fisiu@opensuse.org
- Update Phalcon to 3.0.2 and use zephir 0.9.5.
* Wed Aug 24 2016 fisiu@opensuse.org
- Update Phalcon to 3.0.1.
* Wed Aug 17 2016 fisiu@opensuse.org
- Compile phalcon-3.0.0 with zephir 0.9.4.
* Sat Jul 30 2016 fisiu@opensuse.org
- Update Phalcon to 3.0.0. Package built with zephir-0.9.3.
* Thu Mar 24 2016 fisiu@opensuse.org
- Phalcon 2.1.0 RC1.
* Thu Mar 10 2016 fisiu@opensuse.org
- Phalcon 2.1.0 beta 2.
* Sun Nov 29 2015 mruz@poczta.onet.pl
- Phalcon 2.0.9
  + Improved overall support of SQL for migrations
  + Fixed bug that double serializes data using Redis adapter
  + Added console:boot event to allow the developer to perform initialization actions
  + Added implementation options allowEmpty for Phalcon\Mvc\Model\Validator\Ip
  + Fixed SQLite bug[#10997] related to setting of index type
  + Added Phalcon\Db\Dialect\Sqlite::listIndexesSql - to generate the SQL to get query list of indexes
  + Fixed MySQL bug[#11036] related to setting of index type
  + Added missed RouteInterface::setHostname, RouteInterface::getHostname
  + Added strict option for ExclusionIn validator
  + Added Phalcon\Text::underscore - to make a phrase underscored instead of spaced
  + Added Phalcon\Text::humanize - to make an underscored or dashed phrase human-readable
  + Added ability to change document class to be returned in ODM through class option
* Sat Sep 26 2015 mruz@poczta.onet.pl
- Phalcon 2.0.8
  + Added Phalcon\Security\Random::base58 - to generate a random base58 string
  + Added Phalcon\Logger\Adapter::isTransaction() to check whether the logger is currently in transaction mode or not (Phalcon 1.3 behavior)
  + Phalcon\Session\Adapter now closes the session when the adapter is destroyed (Phalcon 1.3 behavior)
  + Fixed fetching of data in modes FETCH_CLASS, FETCH_INTO and FETCH_FUNC in Phalcon\Db
  + Added missing code property in Phalcon\Validation\Message available in Phalcon 1.3.x
  + Added Phalcon\Db\Column::TYPE_TIMESTAMP to allow migrations on these kind of columns
  + Added Phalcon\Db\ColumnInterface::hasDefault to check if a column has a default value declared in its database column definition
  + Fixed determining of default value for column in Phalcon\Db\Dialect\MySQL, Phalcon\Db\Dialect\Sqlite and Phalcon\Db\Dialect\Postgresql classes
  + Now Phalcon\Mvc\Model::__call invokes finders as in __callStatic
  + Fixed Phalcon\Db\Dialect\Postgresql::getColumnDefinition for BIGINT and BOOLEAN data types
  + Fixed BOOLEAN default value in Phalcon\Db\Dialect\Postgresql
  + Added Phalcon\Validation\Validator\CreditCard - validation credit card number using luhn algorithm
* Tue Aug 18 2015 mruz@poczta.onet.pl
- Phalcon 2.0.7
  + Image\Adapter\Gd::save() no longer fails if the method or the instance is created with a filename without an extension
  + Fixed segfault and implementation of Image\Adapter\Imagick::text()
  + Exceptions thrown in Volt compiler are now Phalcon\Mvc\View\Engine\Exception
  + Now you can import macros from other files using {%% include "file.volt" %%}
  + Undefined function calls fall back to macro calls in Volt templates
  + Automatic bound parameters in Mvc\Model\Criteria now uses a different prefix
  + than Mvc\Model\Query\Builder to avoid collisions
  + Added Cache\Multiple::flush() to flush the cache backends added to the multiple system
  + Fixed Session\Bag::remove()
  + Session\Bag::destroy() eliminates any temporary data in the variables bag
  + afterCreate/afterUpdate are only called if saving related records was successful
  + Added an optional parameter removeData to Session\Adapter::remove() to remove any data in $_SESSION that belongs to the uniqueId or the whole session data
  + Now session variables making use of unique prefixes use # as internal separator
  + Added parameter that changes the default operator for conditions in method Mvc\Model\Criteria::fromImput() #10749
  + Added \Phalcon\Queue\Beanstalk::listTubes() to get list of a tubes
  + Added a fix to avoid that a table present in many sub-queries causes invalid SQL generation
  + Add CookieInterface, update Cookie and Cookies to use this interface - Decoupling Cookies and Cookie - Check Session state before using it in Cookie. #10789
  + Fixed merge of two Phalcon\Config instances that contains object values different than Phalcon\Config compatible instances
  + When creating tables in Postgres, inline PRIMARY keys are now escaped properly#10797
  + Fixed incorrect generation of SELECT COUNT(*) causing unexpected exceptions when phqlLiterals is disabled
  + Added Phalcon\Security\Random - secure random number generator class. Provides secure random number generator which is suitable for generating session key in HTTP cookies, etc
* Wed Jul 22 2015 mruz@poczta.onet.pl
- Phalcon 2.0.6
  + Builds in TravisCI now uses Docker to perform faster builds
  + Added Http\Response::setCache() to easily set cache headers.
  + When a beanstalkd connection is closed the adapter does not produce a notice anymore
  + Default separator in Text::increment is now _ (underscore)
  + Using tel_field in Volt now generates correct PHP code
  + SQL generated by PostgreSQL dialect in dropTable and dropView is now correct
  + Errors generated in Cache\Backend\Memcached now shows the result code to easily debug problems
  + Fixed LIMIT/OFFSET SQL generation in Mvc\Model\Query\Builder
  + Fixed Logger\Formatter\Line to match 1.3.x behavior
  + Fixed warning when castOnHydrate' is true #10648
  + Added name before int/float/numeric/string/bool/null/other variables in Debug\Dump::output
  + Now Validation\Validator\Identical allows both 'accepted' and 'value' as value to keep backwards compatibility
  + Added \Phalcon\Mvc\Model\MetaData\Redis adapter.
  + Added Redis Session adapter
  + Fixed bug in Mvc\Model\Criteria::fromInput unallowing it to use renamed columns
  + Fixed bug in Http\Request getRawBody()/getPut() clears input buffer #10694
- Phalcon 2.0.5
  + Fixed a bug that makes that attaching an events manager to an Mvc\Application causes view->render() not being called
  + Fixed bug that makes generated SQL statements using FOR UPDATE not being parsed correctly
  + The email filter now no longer removes the ' character #10603
  + When an array is bound the cached representation in PHQL makes the SQL being incorrectly generated the second time.
  + Added \Phalcon\Mvc\Model\MetaData\Memcache and \Phalcon\Mvc\Model\MetaData\Libmemcached adapters
  + Fixed a bug that makes macro can't be called recursively in Volt
* Wed Jul  8 2015 mruz@poczta.onet.pl
- Phalcon 2.0.4
  + Fixed bug in Phalcon\Mvc\Model::update() that mistakenly throws an exception when the record does exist
  + Now links in Phalcon\Debug point to https://api.phalconphp.com instead of http://docs.phalconphp.com
  + Implemented a more versatile way to assign variables in Volt allowing to assign properties and array indexes
  + Improved generation of macros in Volt using anonymous functions instead of plain PHP functions, this allow to bind the adapter object and inject services within them
  + Fixed generation and validation of default parameters in Volt's macros
  + Added Phalcon\Assets\Manager::getCollections() to return all collections registered #2488
  + Now Phalcon\Mvc\Url::getStatic() generates URLs from routes
  + Introduced Phalcon\Mvc\EntityInterface to allow parameters receive both Phalcon\Mvc\Model and Phalcon\Mvc\Collection instances. This interface allow Mvc\Model\Validators being used in Mvc\Collection
  + Added Phalcon\Session\Adapter::setName() to change the session name
  + Added BIGINT column type support in Phalcon\Db
  + Added new types Phalcon\Db\Column::BLOB and Phalcon\Db\Column::DOUBLE #10506
  + Automatic binding of Large Object data (LOB) in the ORM
  + Support for BIT types in MySQL with binding as booleans
  + Added Phalcon\Flash\Direct::output() allowing to place flash messages in a specific place of the view #629
  + Added 'autoescape' option that allows to globally enable autoescape in any Volt template
  + Added readAttribute/writeAttribute to Phalcon\Mvc\Collection\Document
  + Added toArray to Phalcon\Mvc\Collection\Document
  + Global setting db.force_casting now forces casting bound parameters to specified bind types
  + Introduced new placeholders in PHQL enclosed in brackets that allow to set the type: {name:str} or {names:array}
  + Now you can bind arrays in bound parameters in PHQL
  + Global setting orm.cast_on_hydrate allow to cast hydrated attributes to the original types in the mapped tables instead of using strings
  + Values in LIMIT/OFFSET clause are now passed using bound parameters in PHQL
  + Allowing late state binding in both Simple/Complex results to allow override Mvc\Model::cloneResultMap
  + Added method distinct() in Phalcon\Mvc\Model\Criteria #10536
  + Added global setting orm.ignore_unknown_columns to ignore unexpected columns when hydrating instances in the ORM This fixes extra auxiliar columns used in Db\Adapter\Pdo\Oracle
  + Added support for afterFetch in Mvc\Collection
  + Added 'beforeMatch' parameter in @Route annotation of Mvc\Router\Annotations
  + Added groupBy/getGroupBy/having/getHaving to Mvc\Model\Criteria
  + Phalcon\Mvc\Model::count() now return values as integer
  + Removed __construct from Phalcon\Mvc\View\EngineInterface
  + Added Phalcon\Debug\Dump::toJson() to return an JSON string of information about a single variable
  + Now instances in Phalcon\Di are built using internal optimizers instead of \ReflectionClass (PHP 5.6)
  + Added Phalcon\Mvc\Model\Validator\IP from incubator
  + Added parameter return defaultValue in Phalcon\Mvc\Model\Validator::getOption()
* Thu Jun 11 2015 mruz@poczta.onet.pl
- Phalcon 2.0.3
* Tue May 26 2015 mruz@poczta.onet.pl
- Phalcon 2.0.2
* Tue Oct 28 2014 mruz@poczta.onet.pl
- Phalcon 1.3.4 release
* Sun Sep 28 2014 mruz@poczta.onet.pl
- Phalcon 1.3.3 release
* Tue Jul  8 2014 mruz@poczta.onet.pl
- Phaclcon 1.3.2 rebuild
* Thu Jun  5 2014 mruz@poczta.onet.pl
- Phalcon 1.3.2 release
* Fri Mar 28 2014 mruz@poczta.onet.pl
- Phalcon 1.3.1 release
* Tue Mar 18 2014 mruz@poczta.onet.pl
- Phalcon 1.3.0 release
* Tue Mar 11 2014 mruz@poczta.onet.pl
- Phalcon 1.3.0 build 11032014
* Mon Mar  3 2014 mruz@poczta.onet.pl
- Phalcon 1.3.0 build 03032014
* Wed Feb 12 2014 mruz@poczta.onet.pl
- Phalcon 1.3.0 build 12022014
* Thu Dec 12 2013 mruz@poczta.onet.pl
- Phalcon 1.3.0 beta 1 release
* Mon Oct 21 2013 mruz@poczta.onet.pl
- Phalcon 1.2.4 release
* Mon Aug 26 2013 mruz@poczta.onet.pl
- Phalcon 1.2.3 release
* Fri Aug  9 2013 mruz@poczta.onet.pl
- Phalcon 1.2.2 release
* Thu Jul 25 2013 mruz@poczta.onet.pl
- Phalcon 1.2.1 release
* Wed Jul 10 2013 mruz@poczta.onet.pl
- Phalcon 1.2.0 release
* Wed Jun 19 2013 mruz@poczta.onet.pl
- Phalcon 1.2 beta 1 release
* Sat Jun  1 2013 mruz@poczta.onet.pl
- PhalconPHP release 1.1.0
